==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/change/vo/ChangematerialrequirementsdetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资需求总计划子表变更
 * 
 * @author generator
 * 
 */
public class ChangematerialrequirementsdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id
    private java.lang.String billCode; // 物资编号
    private java.lang.String name; // 物资名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String spec; // 物资规格
    private java.lang.String measuringUnit; // 计量单位
    private java.lang.String base; // 基础
    private java.math.BigDecimal main; // 主体
    private java.math.BigDecimal decorate; // 装修
    private java.math.BigDecimal subtotal; // 小计
    private java.math.BigDecimal otherNum; // 其它数量
    private java.math.BigDecimal total; // 合计数量
    private java.lang.String remarks; // 备注
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 物资编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 物资编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 物资规格
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 物资规格
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 基础
     */
    public java.lang.String getBase() {
        return base;
    }

    /**
     * 基础
     */
    public void setBase(java.lang.String base) {
        this.base = base;
    }
    /**
     * 主体
     */
    public java.math.BigDecimal getMain() {
        return main;
    }

    /**
     * 主体
     */
    public void setMain(java.math.BigDecimal main) {
        this.main = main;
    }
    /**
     * 装修
     */
    public java.math.BigDecimal getDecorate() {
        return decorate;
    }

    /**
     * 装修
     */
    public void setDecorate(java.math.BigDecimal decorate) {
        this.decorate = decorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 其它数量
     */
    public java.math.BigDecimal getOtherNum() {
        return otherNum;
    }

    /**
     * 其它数量
     */
    public void setOtherNum(java.math.BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    /**
     * 合计数量
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计数量
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/change/vo/ChangematerialrequirementsdetailVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资需求总计划子表变更
 * 
 * @author generator
 * 
 */
public class ChangematerialrequirementsdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id
    private java.lang.String billCode; // 物资编号
    private java.lang.String name; // 物资名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String spec; // 物资规格
    private java.lang.String measuringUnit; // 计量单位
    private java.lang.String base; // 基础
    private java.math.BigDecimal main; // 主体
    private java.math.BigDecimal decorate; // 装修
    private java.math.BigDecimal subtotal; // 小计
    private java.math.BigDecimal otherNum; // 其它数量
    private java.math.BigDecimal total; // 合计数量
    private java.lang.String remarks; // 备注

    private java.lang.String sort;
    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 物资编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 物资编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 物资规格
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 物资规格
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 基础
     */
    public java.lang.String getBase() {
        return base;
    }

    /**
     * 基础
     */
    public void setBase(java.lang.String base) {
        this.base = base;
    }
    /**
     * 主体
     */
    public java.math.BigDecimal getMain() {
        return main;
    }

    /**
     * 主体
     */
    public void setMain(java.math.BigDecimal main) {
        this.main = main;
    }
    /**
     * 装修
     */
    public java.math.BigDecimal getDecorate() {
        return decorate;
    }

    /**
     * 装修
     */
    public void setDecorate(java.math.BigDecimal decorate) {
        this.decorate = decorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 其它数量
     */
    public java.math.BigDecimal getOtherNum() {
        return otherNum;
    }

    /**
     * 其它数量
     */
    public void setOtherNum(java.math.BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    /**
     * 合计数量
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计数量
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
